decode_generic

Function decode_generic 

pub const fn decode_generic<'dst>(
    src: &[u8],
    dst: &'dst mut [MaybeUninit<u8>],
) -> Result<&'dst [u8], InvalidInput>
decode(), but const-evaluable at the cost of performance.

The decode! macro wraps this function and is the preferred way to call it in const contexts, such as when initializing a const or static variable.

Errors

  1. The input contains invalid characters.
  2. The input contains an odd number of nibbles.
  3. The len of the output buffer is insufficient.