pub struct Display<T> { /* private fields */ }Expand description
A wrapper for displaying a byte slice as a hexadecimal string.
Examples
let bytes = &[0xde, 0xad, 0xbe, 0xef];
let displayed = fashex::Display::from(bytes);
assert_eq!(format!("{}", &displayed), "deadbeef");
assert_eq!(format!("{:X}", &displayed), "DEADBEEF");
assert_eq!(format!("{:#x}", &displayed), "0xdeadbeef");
assert_eq!(format!("{:#X}", &displayed), "0xDEADBEEF");Notes
The input bytes should be less than or equal to 128 bytes in length when
the alloc feature is disabled.
Implementations